##  Using SAP-Specific Shapes in Diagrams
While working with diagrams created using the SAP BTP reference architecture templates or in any diagram actually, you can use SAP-specific shapes to ensure consistency and clarity. These shapes help accurately represent various components and align with established standards.
To use the SAP-specific shapes, you first need to add the SAP shape libraries to the editor's left-side panel. Here's how:
  1. Click + More Shapes at the bottom of the left side panel.
  2. Under the Networking group, check the box against SAP.


YesNo
Send
